;; Generated package description from relint.el  -*- no-byte-compile: t -*-
(define-package "relint" "2.2.0.20260205.105130" "Elisp regexp mistake finder" '((xr "2.0") (emacs "27.1")) :commit "04515f5ffd2b0e4d8e638fbcd0af8954b8113d9b" :authors '(("Mattias Engdegård" . "mattias.engdegard@gmail.com")) :maintainer '("Mattias Engdegård" . "mattias.engdegard@gmail.com") :keywords '("lisp" "regexps") :url "https://github.com/mattiase/relint")
